@@ -1,7 +1,7 @@
 package Test::Script;
 
 # ABSTRACT: Basic cross-platform tests for scripts
-our $VERSION = '1.20'; # VERSION
+our $VERSION = '1.23'; # VERSION
 
 
 use 5.008001;
@@ -13,9 +13,8 @@ use File::Spec;
 use File::Spec::Unix;
 use Probe::Perl;
 use Capture::Tiny qw( capture );
-use Test::Builder ();
+use Test2::API qw( context );
 use File::Temp qw( tempdir );
-use File::Path qw( rmtree );
 use IO::Handle;
 
 our @ISA     = 'Exporter';
@@ -36,11 +35,24 @@ our @EXPORT  = qw{
 sub import {
   my $self = shift;
   my $pack = caller;
-  my $test = Test::Builder->new;
-  $test->exported_to($pack);
   if(defined $_[0] && $_[0] =~ /^(?:no_plan|skip_all|tests)$/)
   {
-    $test->plan(@_);
+    # icky back compat.
+    # do not use.
+    my $ctx = context();
+    if($_[0] eq 'tests')
+    {
+      $ctx->plan($_[1]);
+    }
+    elsif($_[0] eq 'skip_all')
+    {
+      $ctx->plan(0, 'SKIP', $_[1]);
+    }
+    else
+    {
+      $ctx->hub->plan('NO PLAN');
+    }
+    $ctx->release;
   }
   foreach ( @EXPORT ) {
     $self->export_to_level(1, $self, $_);
@@ -87,11 +99,12 @@ sub script_compiles {
     $error eq '' and $exit == 0 and $signal == 0 and $stderr =~ /syntax OK\s+\z/si
   );
 
-  my $test = Test::Builder->new;
-  $test->ok( $ok, $_[0] || "Script $unix compiles" );
-  $test->diag( "$exit - $stderr" ) unless $ok;
-  $test->diag( "exception: $error" ) if $error;
-  $test->diag( "signal: $signal" ) if $signal;
+  my $ctx = context();
+  $ctx->ok( $ok, $_[0] || "Script $unix compiles" );
+  $ctx->diag( "$exit - $stderr" ) unless $ok;
+  $ctx->diag( "exception: $error" ) if $error;
+  $ctx->diag( "signal: $signal" ) if $signal;
+  $ctx->release;
 
   return $ok;
 }
@@ -176,11 +189,12 @@ sub script_runs {
   my $signal = $? ? ($? & 127) : 0;
   my $ok     = !! ( $error eq '' and $exit == $opt->{exit} and $signal == $opt->{signal} );
 
-  my $test = Test::Builder->new;
-  $test->ok( $ok, $_[0] || "Script $unix runs" );
-  $test->diag( "$exit - $stderr" ) unless $ok;
-  $test->diag( "exception: $error" ) if $error;
-  $test->diag( "signal: $signal" ) unless $signal == $opt->{signal};
+  my $ctx = context();
+  $ctx->ok( $ok, $_[0] || "Script $unix runs" );
+  $ctx->diag( "$exit - $stderr" ) unless $ok;
+  $ctx->diag( "exception: $error" ) if $error;
+  $ctx->diag( "signal: $signal" ) unless $signal == $opt->{signal};
+  $ctx->release;
 
   return $ok;
 }
@@ -192,18 +206,19 @@ sub _like
   my $ok = $regex ? $text =~ $pattern : $text eq $pattern;
   $ok = !$ok if $not;
 
-  my $test = Test::Builder->new;
-  $test->ok( $ok, $name );
+  my $ctx = context;
+  $ctx->ok( $ok, $name );
   unless($ok) {
-    $test->diag( "The output" );
-    $test->diag( "  $_") for split /\n/, $text;
-    $test->diag( $not ? "does match" : "does not match" );
+    $ctx->diag( "The output" );
+    $ctx->diag( "  $_") for split /\n/, $text;
+    $ctx->diag( $not ? "does match" : "does not match" );
     if($regex) {
-      $test->diag( "  $pattern" );
+      $ctx->diag( "  $pattern" );
     } else {
-      $test->diag( "  $_" ) for split /\n/, $pattern;
+      $ctx->diag( "  $_" ) for split /\n/, $pattern;
     }
   }
+  $ctx->release;
 
   $ok;
 }
@@ -346,15 +361,17 @@ Test::Script - Basic cross-platform tests for scripts
 
 =head1 VERSION
 
-version 1.20
+version 1.23
 
 =head1 SYNOPSIS
 
- use Test::More tests => 2;
+ use Test2::V0;
  use Test::Script;
  
  script_compiles('script/myscript.pl');
  script_runs(['script/myscript.pl', '--my-argument']);
+ 
+ done_testing;
 
 =head1 DESCRIPTION
 
@@ -540,7 +557,7 @@ L<Capture::Tiny> instead and explicitly do not support saving STDIN handles.
 
 =head1 SEE ALSO
 
-L<Test::Script::Run>, L<Test::More>
+L<Test::Script::Run>, L<Test2::Suite>
 
 =head1 AUTHOR
 
